@@ -22,9 +22,10 @@
 #include <map>
 #include <cassert>
 
+#include "test_macros.h"
 #include "is_transparent.h"
 
-#if _LIBCPP_STD_VER <= 11
+#if TEST_STD_VER <= 11
 #error "This test requires is C++14 (or later)"
 #else
 
@@ -33,7 +34,7 @@ int main()
     {
     typedef std::multimap<int, double, transparent_less_not_a_type> M;
 
-    M().find(C2Int{5});
+    TEST_IGNORE_NODISCARD M().find(C2Int{5});
     }
 }
-#endif
\ No newline at end of file
+#endif
