@@ -7,6 +7,8 @@
 //
 //===----------------------------------------------------------------------===//
 
+// UNSUPPORTED: c++98, c++03
+
 // template<class E> class initializer_list;
 
 // initializer_list();
@@ -20,10 +22,9 @@ struct A {};
 
 int main()
 {
-#ifndef _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
     std::initializer_list<A> il;
     assert(il.size() == 0);
-#endif  // _LIBCPP_HAS_NO_GENERALIZED_INITIALIZERS
+
 #if TEST_STD_VER > 11
     constexpr std::initializer_list<A> il2;
     static_assert(il2.size() == 0, "");
