@@ -12,6 +12,7 @@
 // is_signed
 
 #include <type_traits>
+#include "test_macros.h"
 
 template <class T>
 void test_is_signed()
@@ -20,6 +21,12 @@ void test_is_signed()
     static_assert( std::is_signed<const T>::value, "");
     static_assert( std::is_signed<volatile T>::value, "");
     static_assert( std::is_signed<const volatile T>::value, "");
+#if TEST_STD_VER > 14
+    static_assert( std::is_signed_v<T>, "");
+    static_assert( std::is_signed_v<const T>, "");
+    static_assert( std::is_signed_v<volatile T>, "");
+    static_assert( std::is_signed_v<const volatile T>, "");
+#endif
 }
 
 template <class T>
@@ -29,6 +36,12 @@ void test_is_not_signed()
     static_assert(!std::is_signed<const T>::value, "");
     static_assert(!std::is_signed<volatile T>::value, "");
     static_assert(!std::is_signed<const volatile T>::value, "");
+#if TEST_STD_VER > 14
+    static_assert(!std::is_signed_v<T>, "");
+    static_assert(!std::is_signed_v<const T>, "");
+    static_assert(!std::is_signed_v<volatile T>, "");
+    static_assert(!std::is_signed_v<const volatile T>, "");
+#endif
 }
 
 class Class
@@ -37,6 +50,8 @@ public:
     ~Class();
 };
 
+struct A; // incomplete
+
 int main()
 {
     test_is_not_signed<void>();
@@ -48,6 +63,7 @@ int main()
     test_is_not_signed<char[]>();
     test_is_not_signed<bool>();
     test_is_not_signed<unsigned>();
+    test_is_not_signed<A>();
 
     test_is_signed<int>();
     test_is_signed<double>();
