@@ -7,6 +7,7 @@
 //
 //===----------------------------------------------------------------------===//
 
+// UNSUPPORTED: c++98, c++03, c++11
 #include <utility>
 #include <complex>
 
@@ -14,11 +15,7 @@
 
 int main()
 {
-#if _LIBCPP_STD_VER > 11
     typedef std::unique_ptr<int> upint;
     std::pair<upint, int> t(upint(new int(4)), 23);
     upint p = std::get<upint>(t);
-#else
-#error
-#endif
 }
